Marked Records -- Web of Science v4.31

| Marked Records |
500 | Records on the marked list |

STEP 1: Select sort and output fields for the entire marked list.

Select sort option: | Select fields to include in addition to the author(s), article title and source.
cited references* | addresses | abstract
language | publisher information | ISSN
document type | keywords | times cited
*Selecting the cited references may cause the server to time out with large numbers of records.

STEP 2: Select action for output.

Jeppsson U, Alex J, Pons MN, et al.
  Status and future trends of ICA in wastewater treatment - a European perspective
  WATER SCI TECHNOL 45 (4-5): 485-494 2002
Gregory PL, Biswas AC, Batt ME
  Musculoskeletal problems of the chest wall in athletes
  SPORTS MED 32 (4): 235-250 2002
Disney RHL
  A troublesome sibling species complex of scuttle flies (Diptera : Phoridae) revisited
  J NAT HIST 33 (8): 1159-1216 AUG 1999
Rosanowski F, Eysholdt U
  Medical expertise prior to voice change surgery in male-to-female transsexuals
  HNO 47 (6): 556-562 JUN 1999

Back to top of Marked Records page

Acceptable Use Policy

Copyright © 2002 Institute for Scientific Information